Struct ZxdgExportedV1

pub struct ZxdgExportedV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
an exported surface handle

An xdg_exported object represents an exported reference to a surface. The exported surface may be referenced as long as the xdg_exported object not destroyed. Destroying the xdg_exported invalidates any relationship the importer may have established using xdg_imported.

See also the Request enum for this interface.

Implementations



impl ZxdgExportedV1

pub fn handle(&self, handle: String)

the exported surface handle

The handle event contains the unique handle of this exported surface reference. It may be shared with any client, which then can use it to import the surface by calling xdg_importer.import. A handle may be used to import the surface multiple times.